@@ -15,3 +15,25 @@
  */
 
 //! `FEEL` definitions.
+
+extern crate chrono;
+extern crate chrono_tz;
+extern crate dmntk_common;
+#[macro_use]
+extern crate lazy_static;
+extern crate regex;
+
+pub mod bif;
+pub mod context;
+pub mod names;
+pub mod temporal;
+pub mod types;
+pub mod values;
+
+#[cfg(test)]
+mod tests {
+  #[test]
+  fn this_should_work() {
+    assert_eq!(4, 2 + 2);
+  }
+}
